﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using JeffreySun.Dwfx;
using JeffreySun.Dwfx.Packing;
using System.IO;
using System.Xml;

namespace JeffreySun.Dwfx.Converting
{
  public class Converter
  {
    private string dwfxFilePath;

    public string DwfxFilePath
    {
      get
      {
        return this.dwfxFilePath;
      }
      set
      {
        if (!File.Exists(value))
        {
          throw new ArgumentNullException("Dwfx File Path");
        }

        this.dwfxFilePath = value;
      }
    }

    public Converter(string path)
    {
      this.DwfxFilePath = path;
    }

    public void ConvertTo(string xamlPath)
    {
      DwfxDocument dwfxDocument = new DwfxDocument(this.DwfxFilePath, FileAccess.Read);
      IDwfxDocumentSequenceReader docSeq = dwfxDocument.DwfxDocumentSequenceReader;

      foreach (IDwfxDocumentReader docReader in docSeq.DwfxManifests)
      {
        docReader.ResolveContent();
        IDwfxGraphicsDictionaryReader dictionaryReader = docReader.DictionaryReader;
        IDwfxGraphicsExtentionReader extensionReader = docReader.ExtensionReader;
        IDwfxObjectDefinitionReader definitionReader = docReader.DefinitionReader;
        IDwfxFixedPageReader pageReader = docReader.CurrentFixedPage;
        List<DwfxFont> Fonts = docReader.FontCollection;

        XmlDocument pageDoc = pageReader.PageDocument;
        XmlNamespaceManager nsmgr = new XmlNamespaceManager(pageDoc.NameTable);
        nsmgr.AddNamespace("xps", "http://schemas.microsoft.com/xps/2005/06");

        // Remove xml declarition
        foreach (XmlNode node in pageDoc.ChildNodes)
        {
            if (node.NodeType == XmlNodeType.XmlDeclaration)
            {
                pageDoc.RemoveChild(node);
                break;
            }
        }

        XmlNode resNode = pageDoc.SelectSingleNode("/*[local-name()='FixedPage' and namespace-uri()='http://schemas.microsoft.com/xps/2005/06']/*[local-name()='Canvas' and namespace-uri()='http://schemas.microsoft.com/xps/2005/06'][1]/*[local-name()='Canvas' and namespace-uri()='http://schemas.microsoft.com/xps/2005/06'][1]/*[local-name()='Canvas.Resources' and namespace-uri()='http://schemas.microsoft.com/xps/2005/06'][1]", nsmgr);
        resNode.RemoveAll();
        
        XmlNodeList paths = pageDoc.DocumentElement.SelectNodes("//xps:Path", nsmgr);
        foreach (XmlNode path in paths)
        {
          //XmlAttribute commandArttr = pageDoc.CreateAttribute("MouseEnter");
          //commandArttr.Value = "OnMouseEnter";
          //if (path.Attributes != null)
          //{
          //  path.Attributes.Append(commandArttr);
          //}

          StringBuilder sb = new StringBuilder();
          foreach (XmlAttribute attri in path.Attributes)
          {
            // Modify border thickness to adopt line weight
            if (attri.LocalName == "StrokeThickness")
            {
              attri.Value = "1";
            }

            if (attri.LocalName == "Name")
            {
              if(docReader.BlockPropertiesDictionary.ContainsKey(attri.Value))
              {
                foreach (DwfxProperty prop in docReader.BlockPropertiesDictionary[attri.Value])
                {
                  sb.Append(prop.Name + ": " + prop.Value + "\t");
                }

              }
            }
          }

          XmlAttribute bindingArttr = pageDoc.CreateAttribute("Tag");
          bindingArttr.Value = sb.ToString();

          path.Attributes.Append(bindingArttr);
        }

        // Remove font reference
        XmlNodeList glyphs = pageDoc.DocumentElement.SelectNodes("//xps:Glyphs", nsmgr);
        foreach (XmlNode glyph in glyphs)
        {
          XmlAttribute attriToRemove = null;
          foreach (XmlAttribute attri in glyph.Attributes)
          {
            if (attri.LocalName == "FontUri")
            {
              attriToRemove = attri;
              break;
            }
          }

          if (attriToRemove != null)
          {
            glyph.Attributes.Remove(attriToRemove);
          }

          //glyph.Attributes.RemoveNamedItem("FontUri", "http://schemas.microsoft.com/xps/2005/06");
        }

        foreach (DwfxFont font in Fonts)
        {
            const int size = 4096;
            Stream stream = font.GetPart().GetStream(FileMode.Open, FileAccess.Read);
            Stream outStream = File.Create(Path.Combine(Path.GetDirectoryName(xamlPath), Path.GetFileName(font.Uri.OriginalString)), size, FileOptions.WriteThrough);
            BinaryWriter writer = new BinaryWriter(outStream);

            byte[] bytes = new byte[4096];
            int numBytes;
            while ((numBytes = stream.Read(bytes, 0, size)) > 0)
                writer.Write(bytes, 0, numBytes);

            writer.Flush();
            writer.Close();
            stream.Close();
        }


        pageDoc.Save(xamlPath);
        pageDoc = null;
        GC.Collect();

        break;
      }
    }

  }
}
