﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO.Packaging;
using System.Xml;
using System.Collections.ObjectModel;
using System.IO;

namespace JeffreySun.Dwfx.Packing
{
  class DwfxDocumentSequenceReader : DwfxPartBase, IDwfxDocumentSequenceReader, INode, IDisposable
  {
    private List<IDwfxDocumentReader> documentCache;
    private bool hasParsedDocuments;
    private PackagePart metroPart;
    private INode parentNode;
    private DwfxThumbnail thumbnail;

    internal DwfxDocumentSequenceReader(DwfxManager dwfxManager, INode parent, PackagePart part) : base(dwfxManager)
    {
        if (part == null)
        {
            throw new ArgumentNullException("part");
        }

        base.Uri = part.Uri;
        this.metroPart = part;
        this.documentCache = new List<IDwfxDocumentReader>();
        this.parentNode = parent;
        this.hasParsedDocuments = false;
    }

    public PackagePart GetPart()
    {
      return this.metroPart;
    }

    private void ParseDocuments()
    {
      Stream input = this.metroPart.GetStream(FileMode.Open);
      if (input.Length > 0L)
      {
        XmlTextReader reader = new XmlTextReader(input);
        while (reader.Read())
        {
          if ((reader.NodeType == XmlNodeType.Element) && (reader.Name == DwfxMarkup.DwfxManifestReference))
          {
            string attribute = reader.GetAttribute(XmlTags.Source);
            if (attribute != null)
            {
              Uri targetUri = new Uri(attribute, UriKind.Relative);
              this.AddDocumentToCache(PackUriHelper.ResolvePartUri(base.Uri, targetUri));
            }
          }
        }
      }
    }

    public ReadOnlyCollection<IDwfxDocumentReader> DwfxManifests
    {
      get
      {
        this.UpdateDocumentCache();
        return new ReadOnlyCollection<IDwfxDocumentReader>(this.documentCache);
      }
    }

    public DwfxThumbnail Thumbnail
    {
      get
      {
        this.EnsureThumbnail();
        return this.thumbnail;
      }
    }

    public IDwfxDocumentReader GetDwfxManifest(Uri documentUri)
    {
      this.UpdateDocumentCache();
      IDwfxDocumentReader reader = null;
      foreach (IDwfxDocumentReader cachedReader in this.documentCache)
      {
        if (documentUri == cachedReader.Uri)
        {
          reader = cachedReader;
        }
      }

      return reader;
    }

    public void Dispose()
    {
      this.documentCache = null;
      this.metroPart = null;
      this.parentNode = null;
      this.thumbnail = null;
    }

    private IDwfxDocumentReader AddDocumentToCache(Uri documentUri)
    {
      PackagePart part = base.CurrentDwfxManager.GetPart(documentUri);
      if (part == null)
      {
        throw new DwfxPackagingException(SR.Get("ReachPackaging_PartNotFound"));
      }

      IDwfxDocumentReader item = new DwfxDocumentReader(base.CurrentDwfxManager, null, part, this.documentCache.Count + 1);
      this.documentCache.Add(item);
      return item;
    }

    private void EnsureThumbnail()
    {
      if (this.thumbnail == null)
      {
        this.thumbnail = base.CurrentDwfxManager.EnsureThumbnail(this, this.metroPart);
      }
    }

    private void UpdateDocumentCache()
    {
      if (!this.hasParsedDocuments)
      {
        this.ParseDocuments();
        this.hasParsedDocuments = true;
      }
    }
  }
}
