﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO.Packaging;
using System.IO;
using System.Xml;

namespace JeffreySun.Dwfx.Packing
{
  public class DwfxGraphicsExtensionReader : DwfxPartBase, INode, IDwfxGraphicsExtentionReader
  {
    private PackagePart metroPart;
    private IDwfxDocumentReader parentNode;
    private Dictionary<string, DwfxExtensionNode> extensions;

    public DwfxGraphicsExtensionReader(DwfxManager dwfxManager, IDwfxDocumentReader parent, PackagePart part)
      : base(dwfxManager)
    {
      base.Uri = part.Uri;
      this.metroPart = part;
      this.parentNode = parent;
      this.extensions = new Dictionary<string, DwfxExtensionNode>();
    }

    public Dictionary<string, DwfxExtensionNode> ExtensionDictionary
    {
      get
      {
        return this.extensions;
      }
    }

    public PackagePart GetPart()
    {
      return this.metroPart;
    }

    public Uri Uri
    {
      get
      {
        return base.Uri;
      }
      set
      {
        base.Uri = value;
      }
    }

    public PackagePart MetroPart
    {
      get
      {
        return this.metroPart;
      }
    }

    public IDwfxDocumentReader ParentNode
    {
      get
      {
        return this.parentNode;
      }
    }

    public void ResolveContent()
    {
      using (Stream xmlStream = this.metroPart.GetStream(FileMode.Open, FileAccess.Read))
      using (XmlTextReader reader = new XmlTextReader(xmlStream))
      {
        while (reader.Read())
        {
          if ((reader.NodeType == XmlNodeType.Element) && (reader.LocalName == XmlTags.Sync))
          {
            DwfxExtensionNode node = new DwfxExtensionNode();
            node.ReferenceName = reader.GetAttribute(XmlTags.RefName);
            using (XmlReader subReader = reader.ReadSubtree())
            {
              while (subReader.Read())
              {
                if ((subReader.NodeType == XmlNodeType.Element) && (subReader.LocalName == XmlTags.ObjectNode))
                {
                  int nodeNumber = 0;
                  if (Int32.TryParse(subReader.GetAttribute(XmlTags.Number), out nodeNumber))
                  {
                    node.ObjectNodeNumber = nodeNumber;
                  }

                  break;
                }
              }
            }

            this.extensions.Add(node.ReferenceName, node);
          }

        }
      }
    }
  }
}
