﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Net.Mime;

namespace JeffreySun.Dwfx.Packing
{
  internal class DwfxMarkup
  {
    private static ContentType _applicationXaml = new ContentType("application/xaml+xml");
    private static ContentType _colorContextContentType = new ContentType("application/vnd.ms-color.iccprofile");
    private const string _colorContextUriPlaceHolder = "placeholder";
    private static ContentType _coreDocumentPropertiesContentType = new ContentType("application/vnd.openxmlformats-package.core-properties+xml");
    private const string _coreDocumentPropertiesRelationshipType = "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties";
    private static ContentType _discardContentType = new ContentType("application/vnd.ms-package.xps-discard-control+xml");
    private const string _ditialSignatureRelationshipType = "http://schemas.openxmlformats.org/package/2006/relationships/digital-signature/signature";
    private const string _documentReference = "DocumentReference";
    private static ContentType _documentSequenceContentType = new ContentType("application/vnd.ms-package.xps-fixeddocumentsequence+xml");
    private const string _documentSequenceNamespace = "http://schemas.microsoft.com/xps/2005/06";
    private static ContentType _documentStructureContentType = new ContentType("application/vnd.ms-package.xps-documentstructure+xml");
    private const string _fixedDocument = "FixedDocument";
    private static ContentType _fixedDocumentContentType = new ContentType("application/vnd.ms-package.xps-fixeddocument+xml");
    private const string _fixedDocumentNamespace = "http://schemas.microsoft.com/xps/2005/06";
    private const string _fixedDocumentSequence = "FixedDocumentSequence";
    private const string _fixedPage = "FixedPage";
    private static ContentType _fixedPageContentType = new ContentType("application/vnd.ms-package.xps-fixedpage+xml");
    private static ContentType _fontContentType = new ContentType("application/vnd.ms-opentype");
    private const string _fontUriPlaceHolder = "placeholder";
    private const string _imageUriPlaceHolder = "placeholder";
    private const string _intent = "Intent";
    private static ContentType _jpgContentType = new ContentType("image/jpeg");
    private const string _jpgExtension = "jpg";
    private static ContentType _obfuscatedContentType = new ContentType("application/vnd.ms-package.obfuscated-opentype");
    private const string _obfuscatedFontExt = ".ODTTF";
    private const string _packageRelationshipUri = "/_rels/.rels";
    private const string _pageContent = "PageContent";
    private const string _pageHeight = "Height";
    private const string _pageResources = "FixedPage.Resources";
    private const string _pageUri = "PageURI";
    private const string _pageWidth = "Width";
    private static ContentType _pngContentType = new ContentType("image/png");
    private const string _pngExtension = "png";
    private static ContentType _printTicketContentType = new ContentType("application/vnd.ms-printing.printticket+xml");
    private const string _printTicketRelationshipName = "http://schemas.microsoft.com/xps/2005/06/printticket";
    private const string _reachPackageStartingPartRelationshipType = "http://schemas.microsoft.com/xps/2005/06/fixedrepresentation";

    private const string _reachDwfxPackageStartingPartRelationshipType = "http://schemas.autodesk.com/dwfx/2007/relationships/documentsequence";
    private const string _dwfxContentSectionType = "com.autodesk.dwf.ePlot";

    private static ContentType _relationshipContentType = new ContentType("application/vnd.openxmlformats-package.relationships+xml");
    private const string _requestedSigner = "SignerName";
    private static ContentType _resourceContentType = new ContentType("application/resource-PLACEHOLDER");
    private const string _resourceDictionary = "ResourceDictionary";
    private static ContentType _resourceDictionaryContentType = new ContentType("application/vnd.ms-package.xps-resourcedictionary+xml");
    private const string _resourceDictionaryUriPlaceHolder = "placeholder";
    private const string _resourceRelationshipName = "http://schemas.microsoft.com/xps/2005/06/required-resource";
    private const string _restrictedFontRelationshipType = "http://schemas.microsoft.com/xps/2005/06/restricted-font";
    private static ContentType _sigCertContentType = new ContentType("application/vnd.openxmlformats-package.digital-signature-certificate");
    private const string _signatureDefinition = "SignatureDefinition";
    private const string _signatureDefinitionNamespace = "http://schemas.microsoft.com/xps/2005/06/signature-definitions";
    private const string _signatureDefinitionRelationshipName = "http://schemas.microsoft.com/xps/2005/06/signature-definitions";
    private const string _signatureDefinitions = "SignatureDefinitions";
    private static ContentType _signatureDefinitionType = new ContentType("application/xml");
    private const string _signBy = "SignBy";
    private const string _signingLocale = "SigningLocation";
    private static ContentType _sigOriginContentType = new ContentType("application/vnd.openxmlformats-package.digital-signature-origin");
    private const string _spotId = "SpotID";
    private const string _spotLocation = "SpotLocation";
    private const string _startX = "StartX";
    private const string _startY = "StartY";
    private const string _storyFragments = "StoryFragments";
    private static ContentType _storyFragmentsContentType = new ContentType("application/vnd.ms-package.xps-storyfragments+xml");
    private const string _storyFragmentsRelationshipName = "http://schemas.microsoft.com/xps/2005/06/storyfragments";
    private const string _structureRelationshipName = "http://schemas.microsoft.com/xps/2005/06/documentstructure";
    private const string _thumbnailRelationshipName = "http://schemas.openxmlformats.org/package/2006/relationships/metadata/thumbnail";
    private static ContentType _tifContentType = new ContentType("image/tiff");
    private static string _tifExtension = "tif";
    private const string _versionExtensiblityNamespace = "http://schemas.openxmlformats.org/markup-compatibility/2006";
    private static ContentType _wdpContentType = new ContentType("image/vnd.ms-photo");
    private const string _wdpExtension = "wdp";
    private static ContentType _wmpContentType = new ContentType("image/vnd.ms-photo");
    private const string _xmlLang = "xml:lang";
    private const string _xmlLangValue = "und";
    private const string _xmlns = "xmlns";
    private static readonly string[] _xmlnsUri = new string[] { "http://schemas.microsoft.com/xps/2005/06", "http://schemas.microsoft.com/xps/2005/06", "http://schemas.microsoft.com/xps/2005/06" };
    private static XmlnsUriContainer _xmlnsUriContainer = new XmlnsUriContainer();
    private const string _xmlnsX = "xmlns:x";
    private const string _xmlnsXSchema = "http://schemas.microsoft.com/xps/2005/06/resourcedictionary-key";

    // Methods
    public static string GetXmlnsUri(int index)
    {
      return _xmlnsUri[index];
    }

    // Properties
    public static ContentType ApplicationXaml
    {
      get
      {
        return _applicationXaml;
      }
    }

    public static ContentType ColorContextContentType
    {
      get
      {
        return _colorContextContentType;
      }
    }

    public static string ColorContextUriPlaceHolder
    {
      get
      {
        return "placeholder";
      }
    }

    public static ContentType CoreDocumentPropertiesType
    {
      get
      {
        return _coreDocumentPropertiesContentType;
      }
    }

    public static string CorePropertiesRelationshipType
    {
      get
      {
        return "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties";
      }
    }

    public static ContentType DiscardContentType
    {
      get
      {
        return _discardContentType;
      }
    }

    public static string DitialSignatureRelationshipType
    {
      get
      {
        return "http://schemas.openxmlformats.org/package/2006/relationships/digital-signature/signature";
      }
    }

    public static string DocumentReference
    {
      get
      {
        return "DocumentReference";
      }
    }

    public static string DwfxManifestReference
    {
      get
      {
        return "ManifestReference";
      }
    }

    public static ContentType DocumentSequenceContentType
    {
      get
      {
        return _documentSequenceContentType;
      }
    }

    public static string DocumentSequenceNamespace
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06";
      }
    }

    public static ContentType DocumentStructureContentType
    {
      get
      {
        return _documentStructureContentType;
      }
    }

    public static string FixedDocument
    {
      get
      {
        return "FixedDocument";
      }
    }

    public static ContentType FixedDocumentContentType
    {
      get
      {
        return _fixedDocumentContentType;
      }
    }

    public static string FixedDocumentNamespace
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06";
      }
    }

    public static string FixedDocumentSequence
    {
      get
      {
        return "FixedDocumentSequence";
      }
    }

    public static string FixedPage
    {
      get
      {
        return "FixedPage";
      }
    }

    public static ContentType FixedPageContentType
    {
      get
      {
        return _fixedPageContentType;
      }
    }

    public static ContentType FontContentType
    {
      get
      {
        return _fontContentType;
      }
    }

    public static ContentType FontObfuscatedContentType
    {
      get
      {
        return _obfuscatedContentType;
      }
    }

    public static string FontUriPlaceHolder
    {
      get
      {
        return "placeholder";
      }
    }

    public static string ImageUriPlaceHolder
    {
      get
      {
        return "placeholder";
      }
    }

    public static string Intent
    {
      get
      {
        return "Intent";
      }
    }

    public static ContentType JpgContentType
    {
      get
      {
        return _jpgContentType;
      }
    }

    public static string JpgExtension
    {
      get
      {
        return "jpg";
      }
    }

    public static string ObfuscatedFontExt
    {
      get
      {
        return ".ODTTF";
      }
    }

    public static string PackageRelationshipUri
    {
      get
      {
        return "/_rels/.rels";
      }
    }

    public static string PageContent
    {
      get
      {
        return "PageContent";
      }
    }

    public static string PageHeight
    {
      get
      {
        return "Height";
      }
    }

    public static string PageResources
    {
      get
      {
        return "FixedPage.Resources";
      }
    }

    public static string PageUri
    {
      get
      {
        return "PageURI";
      }
    }

    public static string PageWidth
    {
      get
      {
        return "Width";
      }
    }

    public static ContentType PngContentType
    {
      get
      {
        return _pngContentType;
      }
    }

    public static string PngExtension
    {
      get
      {
        return "png";
      }
    }

    public static ContentType PrintTicketContentType
    {
      get
      {
        return _printTicketContentType;
      }
    }

    public static string PrintTicketRelationshipName
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06/printticket";
      }
    }

    public static string ReachPackageStartingPartRelationshipType
    {
      get
      {
        return _reachPackageStartingPartRelationshipType;
      }
    }

    public static string ReachDwfxPackageStartingPartRelationshipType
    {
      get
      {
        return _reachDwfxPackageStartingPartRelationshipType;
      }
    }

    public static ContentType RelationshipContentType
    {
      get
      {
        return _relationshipContentType;
      }
    }

    public static string RequestedSigner
    {
      get
      {
        return "SignerName";
      }
    }

    public static ContentType ResourceContentType
    {
      get
      {
        return _resourceContentType;
      }
    }

    public static string ResourceDictionary
    {
      get
      {
        return "ResourceDictionary";
      }
    }

    public static ContentType ResourceDictionaryContentType
    {
      get
      {
        return _resourceDictionaryContentType;
      }
    }

    public static string ResourceDictionaryUriPlaceHolder
    {
      get
      {
        return "placeholder";
      }
    }

    public static string ResourceRelationshipName
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06/required-resource";
      }
    }

    public static string RestrictedFontRelationshipType
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06/restricted-font";
      }
    }

    public static ContentType SigCertContentType
    {
      get
      {
        return _sigCertContentType;
      }
    }

    public static string SignatureDefinition
    {
      get
      {
        return "SignatureDefinition";
      }
    }

    public static string SignatureDefinitionNamespace
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06/signature-definitions";
      }
    }

    public static string SignatureDefinitionRelationshipName
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06/signature-definitions";
      }
    }

    public static string SignatureDefinitions
    {
      get
      {
        return "SignatureDefinitions";
      }
    }

    public static ContentType SignatureDefintionType
    {
      get
      {
        return _signatureDefinitionType;
      }
    }

    public static string SignBy
    {
      get
      {
        return "SignBy";
      }
    }

    public static string SigningLocale
    {
      get
      {
        return "SigningLocation";
      }
    }

    public static ContentType SigOriginContentType
    {
      get
      {
        return _sigOriginContentType;
      }
    }

    public static string SpotId
    {
      get
      {
        return "SpotID";
      }
    }

    public static string SpotLocation
    {
      get
      {
        return "SpotLocation";
      }
    }

    public static string StartX
    {
      get
      {
        return "StartX";
      }
    }

    public static string StartY
    {
      get
      {
        return "StartY";
      }
    }

    public static string StoryFragments
    {
      get
      {
        return "StoryFragments";
      }
    }

    public static ContentType StoryFragmentsContentType
    {
      get
      {
        return _storyFragmentsContentType;
      }
    }

    public static string StoryFragmentsRelationshipName
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06/storyfragments";
      }
    }

    public static string StructureRelationshipName
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06/documentstructure";
      }
    }

    public static string ThumbnailRelationshipName
    {
      get
      {
        return "http://schemas.openxmlformats.org/package/2006/relationships/metadata/thumbnail";
      }
    }

    public static ContentType TifContentType
    {
      get
      {
        return _tifContentType;
      }
    }

    public static string TifExtension
    {
      get
      {
        return _tifExtension;
      }
    }

    public static string VersionExtensiblityNamespace
    {
      get
      {
        return "http://schemas.openxmlformats.org/markup-compatibility/2006";
      }
    }

    public static ContentType WdpContentType
    {
      get
      {
        return _wdpContentType;
      }
    }

    public static string WdpExtension
    {
      get
      {
        return "wdp";
      }
    }

    public static ContentType WmpContentType
    {
      get
      {
        return _wmpContentType;
      }
    }

    public static string XmlLang
    {
      get
      {
        return "xml:lang";
      }
    }

    public static string XmlLangValue
    {
      get
      {
        return "und";
      }
    }

    public static string Xmlns
    {
      get
      {
        return "xmlns";
      }
    }

    public static XmlnsUriContainer XmlnsUri
    {
      get
      {
        return _xmlnsUriContainer;
      }
    }

    public static string XmlnsX
    {
      get
      {
        return "xmlns:x";
      }
    }

    public static string XmlnsXSchema
    {
      get
      {
        return "http://schemas.microsoft.com/xps/2005/06/resourcedictionary-key";
      }
    }

    public static string DwfxContentSectionType
    {
      get
      {
        return _dwfxContentSectionType;
      }
    }


    // Nested Types
    internal class XmlnsUriContainer
    {
      // Properties
      public string this[int index]
      {
        get
        {
          return DwfxMarkup.GetXmlnsUri(index);
        }
      }
    }
  }

 

}
