﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO.Packaging;
using System.IO;
using System.Xml;

namespace JeffreySun.Dwfx.Packing
{
  public class DwfxObjectDefinitionReader : DwfxPartBase, IDwfxObjectDefinitionReader, INode
  {
    private PackagePart metroPart;
    private IDwfxDocumentReader parentNode;
    private Dictionary<string, List<DwfxProperty>> properties;
    private Dictionary<int, DwfxObject> objects;
    private Dictionary<int, DwfxInstance> instances;

    public DwfxObjectDefinitionReader(DwfxManager dwfxManager, IDwfxDocumentReader parent, PackagePart part)
      : base(dwfxManager)
    {
      base.Uri = part.Uri;
      this.metroPart = part;
      this.parentNode = parent;

      this.properties = new Dictionary<string, List<DwfxProperty>>();
      this.objects = new Dictionary<int, DwfxObject>();
      this.instances = new Dictionary<int, DwfxInstance>();
    }

    public PackagePart MetroPart
    {
      get
      {
        return this.metroPart;
      }
    }

    public IDwfxDocumentReader ParentNode
    {
      get
      {
        return this.parentNode;
      }
    }

    public Dictionary<string, List<DwfxProperty>> PropertiesDictionary
    {
      get
      {
        return this.properties;
      }
    }

    public Dictionary<int, DwfxObject> ObjectsDictionary
    {
      get
      {
        return this.objects;
      }
    }

    public Dictionary<int, DwfxInstance> InstancesDictionary
    {
      get
      {
        return this.instances;
      }
    }

    public PackagePart GetPart()
    {
      return this.metroPart;
    }

    public Uri Uri
    {
      get
      {
        return base.Uri;
      }
      set
      {
        base.Uri = value;
      }
    }


    public void ResolveContent()
    {
      using(Stream stream = this.metroPart.GetStream(FileMode.Open, FileAccess.Read))
      using (XmlTextReader reader = new XmlTextReader(stream))
      {
        while (reader.Read())
        {
          if (reader.NodeType == XmlNodeType.Element)
          {
            if (reader.LocalName == XmlTags.Properties)
            {
              string id = reader.GetAttribute(XmlTags.Id);
              if (!string.IsNullOrEmpty(id))
              {
                List<DwfxProperty> props = new List<DwfxProperty>();
                using (XmlReader subReader = reader.ReadSubtree())
                {
                  while (subReader.Read())
                  {
                    if (subReader.NodeType == XmlNodeType.Element && subReader.LocalName == XmlTags.Property)
                    {
                      DwfxProperty property = new DwfxProperty();
                      property.Name = subReader.GetAttribute(XmlTags.Name);
                      property.Value = subReader.GetAttribute(XmlTags.Value);
                      property.Category = subReader.GetAttribute(XmlTags.Category);

                      props.Add(property);

                      break;
                    }
                  }

                  subReader.Close();
                }

                this.properties.Add(id, props);
              }
            }
            else if (reader.LocalName == XmlTags.Object)
            {
              DwfxObject obj = new DwfxObject();
              obj.Id = Int32.Parse(reader.GetAttribute(XmlTags.Id));

              using (XmlReader subReader = reader.ReadSubtree())
              {
                while (subReader.Read())
                {
                  if (subReader.NodeType == XmlNodeType.Element && subReader.LocalName == XmlTags.Properties)
                  {
                    obj.propertyGroupId = subReader.GetAttribute(XmlTags.Id);
                    obj.propertyGroupRefId = subReader.GetAttribute(XmlTags.Refs).Trim();
                    break;
                  }
                }

                subReader.Close();
              }

              this.objects.Add(obj.Id, obj);
            }
            else if (reader.LocalName == XmlTags.Instance)
            {
              DwfxInstance instance = new DwfxInstance();
              instance.Id = reader.GetAttribute(XmlTags.Id);
              instance.ObjectId = Int32.Parse(reader.GetAttribute(XmlTags.Obj));
              instance.NodeId = Int32.Parse(reader.GetAttribute(XmlTags.Nodes));

              this.instances.Add(instance.NodeId, instance);
            }
          }
        }
      }
    }
  }
}
